@@ -6,4 +6,5 @@ from .test.complexity import ComplexityResult
 from .test.memory import MemoryResult
 from .teardown.cleanup import CleanupResult
 from .resource import Context, File, Executable, ExecutableFile
-from .task import GenericResult
+from .setup import SetupResult
+from .teardown import TeardownResult
