@@ -6,17 +6,22 @@ from dataclasses import dataclass, field
 from ..log import log
 
 
-@dataclass
-class Result(abc.ABC):
+@dataclass(init=False)
+class Result(Exception, abc.ABC):
     """The result of a test."""
 
     complete: bool
     passed: bool
-    details: dict = field(default_factory=dict)
+    details: dict
 
     kind: str = field(init=False)
     task: "Task" = field(init=False)
 
+    def __init__(self, complete: bool, passed: bool, details: dict):
+        self.complete = complete
+        self.passed = passed
+        self.details = details
+
     def __str__(self):
         return "passed" if self.complete and self.passed else "failed"
 
@@ -32,15 +37,6 @@ class Result(abc.ABC):
         return cls(complete=False, passed=False)
 
 
-class GenericResult(Result):
-    """Can be used for generic tests."""
-
-    kind = "generic"
-
-    def __init__(self, passed: bool = True, complete: bool = True, **details):
-        super().__init__(complete=complete, passed=passed, details=details)
-
-
 TResult = TypeVar("TResult", bound=Result)
 
 
